==> xl-react-components-0.16.62.tgz: package/tests/e2e/dsl/component/dip/dip-map-string-string.js <==
import {Action, Expectation} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';

const getRow = (cellNumber) => `.testComponent .xl-virtualized-table-row:nth-child(${cellNumber})`;

export const clearFilter = () =>
    Action.click('.testComponent .search-panel .xl-react-btn-close');

export const clickOnFilter = () =>
    Action.click('.testComponent .search-panel input[type="text"]');

export const clickOnKeyHeader = () =>
    Action.click('.testComponent .xl-virtualized-table-header-cell:nth-child(1) .sort-icons');

export const expectFilterPresent = () =>
    Expectation.present('.testComponent .search-panel');

export const expectAddButtonEnabled = () =>
    Expectation.enabled('.testComponent .xl-react-components-input .add-row-button');

export const expectAddButtonPresent = () =>
    Expectation.present('.testComponent .xl-react-components-input .add-row-button');

export const expectKeyCellValue = (cellNumber, value) =>
    Expectation.attributeContainsValue(`${getRow(cellNumber)} .key-div input`, 'value', value);

export const expectReadonlyKeyCell = (cellNumber) =>
    Expectation.hasAttribute(`${getRow(cellNumber)} .key-div input`, 'readonly');

export const expectReadonlyValueCell = (cellNumber) =>
    Expectation.hasAttribute(`${getRow(cellNumber)} .value-div textarea`, 'readonly');

export const expectKeyCellPlaceholder = (cellNumber, placeholder) => {
    const selector = `${getRow(cellNumber)} .key-div input`;
    Expectation.attributeContainsValue(selector, 'placeholder', placeholder);
};

export const expectDuplicatedKey = (duplicatedKey) => {
    const selector = '.testComponent .xl-react-alert-error.xl-react-alert-message';
    Expectation.textContains(selector, duplicatedKey);
    Expectation.textContains(selector, 'is already in use.');
};

export const expectRemoveEntryPresent = (entryNumber) =>
    Expectation.present(`${getRow(entryNumber)} .xl-react-btn-close`);

export const expectRemoveEntryNotPresent = (entryNumber) =>
    Expectation.notPresent(`${getRow(entryNumber)} .xl-react-btn-close`);

export const expectValueCellValue = (cellNumber, value, encrypted) => encrypted ?
    Expectation.attributeContainsValue(`${getRow(cellNumber)} .value-div input`, 'value', value) :
    Expectation.attributeContainsValue(`${getRow(cellNumber)} .value-div textarea`, 'value', value);

export const expectValueCellPlaceholder = (cellNumber, placeholder, encrypted) => {
    let selector;
    if (encrypted) {
        selector = `${getRow(cellNumber)} .value-div input`;
    } else {
        selector = `${getRow(cellNumber)} .value-div textarea`;
    }
    Expectation.attributeContainsValue(selector, 'placeholder', placeholder);
};

export const expectValueCellBePasswordType = (cellNumber) => {
    const selector = `${getRow(cellNumber)} .value-div input`;
    Expectation.attributeContainsValue(selector, 'type', 'password');
};

export const removeEntry = (entryNumber) =>
    Action.click(`${getRow(entryNumber)} .xl-react-btn-close`);

export const setKeyValue = (cellNumber, value, encrypted) => {
    const selector = `${getRow(cellNumber)} .key-div input`;
    Action.typeText(selector, value);
    if (encrypted) {
        Action.click(`${getRow(cellNumber)} .value-div input`);
    } else {
        Action.click(`${getRow(cellNumber)} .value-div textarea`);
    }
    expectKeyCellValue(cellNumber, value);
};

export const setEntry = (entryNumber, key, value) => {
    const keySelector = `${getRow(entryNumber)} .key-div input`;
    Action.typeText(keySelector, key);

    const valueSelector = `${getRow(entryNumber)} .value-div textarea`;
    Action.typeText(valueSelector, value);
};

export const setFilterValue = (value) =>
    Action.typeText('.testComponent .search-panel input[type="text"]', value);

export const expectNoSearchResults = () => {
    const firstRow = `${getRow(1)} input`;
    Expectation.notPresent(firstRow);
};

export const expectKeyInputFocused = () => {
    const keyInputPlaceholder = 'Add key...';
    browser.driver.sleep(400);
    browser.driver.switchTo().activeElement()
        .getAttribute('placeholder')
        .then((placeholder) => expect(placeholder).toEqual(keyInputPlaceholder)
        );
};

export const clickAddButton = (encrypted) => {
    Action.click('.testComponent .xl-react-components-input .add-row-button');
    expectKeyCellValue(1, '');
    if (encrypted) {
        expectValueCellValue(1, '', true);
        expectValueCellPlaceholder(1, 'Add value...', true);
    } else {
        expectValueCellValue(1, '');
        expectValueCellPlaceholder(1, 'Add value...');
    }
    expectKeyCellPlaceholder(1, 'Add key...');
};

const DipMapStringString = {
    ...XlComponent,
    clearFilter,
    clickAddButton,
    clickOnFilter,
    clickOnKeyHeader,
    expectFilterPresent,
    expectAddButtonPresent,
    expectAddButtonEnabled,
    expectKeyCellValue,
    expectReadonlyKeyCell,
    expectReadonlyValueCell,
    expectKeyCellPlaceholder,
    expectDuplicatedKey,
    expectRemoveEntryPresent,
    expectRemoveEntryNotPresent,
    expectValueCellValue,
    expectValueCellPlaceholder,
    expectValueCellBePasswordType,
    removeEntry,
    setKeyValue,
    setEntry,
    setFilterValue,
    expectNoSearchResults,
    expectKeyInputFocused
};

export default DipMapStringString;
global.DipMapStringString = DipMapStringString;

==> xl-react-components-0.18.103.tgz: package/tests/e2e/dsl/component/dip/dip-map-string-string.js <==
import {Action, Expectation} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';

const getRow = (cellNumber) => `.testComponent .xl-virtualized-table-row:nth-child(${cellNumber})`;

export const clearFilter = () =>
    Action.click('.testComponent .search-panel .xl-react-btn-close');

export const clickOnFilter = () =>
    Action.click('.testComponent .search-panel input[type="text"]');

export const clickOnKeyHeader = () =>
    Action.click('.testComponent .xl-virtualized-table-header-cell:nth-child(1) .sort-icons');

export const expectFilterPresent = () =>
    Expectation.present('.testComponent .search-panel');

export const expectAddButtonEnabled = () =>
    Expectation.enabled('.testComponent .xl-react-components-input .add-row-button');

export const expectAddButtonPresent = () =>
    Expectation.present('.testComponent .xl-react-components-input .add-row-button');

export const expectKeyCellValue = (cellNumber, value) =>
    Expectation.attributeContainsValue(`${getRow(cellNumber)} .key-div input`, 'value', value);

export const expectReadonlyKeyCell = (cellNumber) =>
    Expectation.hasAttribute(`${getRow(cellNumber)} .key-div input`, 'readonly');

export const expectReadonlyValueCell = (cellNumber) =>
    Expectation.hasAttribute(`${getRow(cellNumber)} .value-div textarea`, 'readonly');

export const expectKeyCellPlaceholder = (cellNumber, placeholder) => {
    const selector = `${getRow(cellNumber)} .key-div input`;
    Expectation.attributeContainsValue(selector, 'placeholder', placeholder);
};

export const expectDuplicatedKey = (duplicatedKey) => {
    const selector = '.testComponent .xl-react-alert-error.xl-react-alert-message';
    Expectation.textContains(selector, duplicatedKey);
    Expectation.textContains(selector, 'is already in use.');
};

export const expectRemoveEntryPresent = (entryNumber) =>
    Expectation.present(`${getRow(entryNumber)} .xl-react-btn-close`);

export const expectRemoveEntryNotPresent = (entryNumber) =>
    Expectation.notPresent(`${getRow(entryNumber)} .xl-react-btn-close`);

export const expectValueCellValue = (cellNumber, value, encrypted) => encrypted ?
    Expectation.attributeContainsValue(`${getRow(cellNumber)} .value-div input`, 'value', value) :
    Expectation.attributeContainsValue(`${getRow(cellNumber)} .value-div textarea`, 'value', value);

export const expectValueCellPlaceholder = (cellNumber, placeholder, encrypted) => {
    let selector;
    if (encrypted) {
        selector = `${getRow(cellNumber)} .value-div input`;
    } else {
        selector = `${getRow(cellNumber)} .value-div textarea`;
    }
    Expectation.attributeContainsValue(selector, 'placeholder', placeholder);
};

export const expectValueCellBePasswordType = (cellNumber) => {
    const selector = `${getRow(cellNumber)} .value-div input`;
    Expectation.attributeContainsValue(selector, 'type', 'password');
};

export const expectValueCellBeTextType = (cellNumber) => {
    const selector = `${getRow(cellNumber)} .value-div input`;
    Expectation.attributeContainsValue(selector, 'type', 'text');
};

export const removeEntry = (entryNumber) =>
    Action.click(`${getRow(entryNumber)} .xl-react-btn-close`);

export const expectShowPasswordIconPresent = (entryNumber) =>
    Expectation.displayed(`${getRow(entryNumber)} .xl-react-widget-reveal-password-icon`);

export const expectShowPasswordIconNotPresent = (entryNumber) =>
    Expectation.notDisplayed(`${getRow(entryNumber)} .xl-react-widget-reveal-password-icon`);

export const clickShowPasswordButton = (entryNumber) =>
    Action.click(`${getRow(entryNumber)} .xl-react-widget-reveal-password-icon`);

export const setKeyValue = (cellNumber, value, encrypted) => {
    const selector = `${getRow(cellNumber)} .key-div input`;
    Action.typeText(selector, value);
    if (encrypted) {
        Action.click(`${getRow(cellNumber)}`);
    } else {
        Action.click(`${getRow(cellNumber)}`);
    }
    expectKeyCellValue(cellNumber, value);
};

export const setEntry = (entryNumber, key, value, encrypted) => {
    const keySelector = `${getRow(entryNumber)} .key-div input`;
    Action.clearText(keySelector);
    Action.typeText(keySelector, key);

    const valueSelector = `${getRow(entryNumber)} .value-div ${encrypted ? 'input' : 'textarea'}`;
    Action.clearText(valueSelector);
    Action.typeText(valueSelector, value);
};

export const setFilterValue = (value) =>
    Action.typeText('.testComponent .search-panel input[type="text"]', value);

export const expectNoSearchResults = () => {
    const firstRow = `${getRow(1)} input`;
    Expectation.notPresent(firstRow);
};

export const expectKeyInputFocused = () => {
    const keyInputPlaceholder = 'Add key...';
    browser.driver.sleep(400);
    browser.driver.switchTo().activeElement()
        .getAttribute('placeholder')
        .then((placeholder) => expect(placeholder).toEqual(keyInputPlaceholder)
        );
};

export const clickAddButton = (encrypted) => {
    Action.click('.testComponent .xl-react-components-input .add-row-button');
    expectKeyCellValue(1, '');
    if (encrypted) {
        expectValueCellValue(1, '', true);
        expectValueCellPlaceholder(1, 'Add value...', true);
    } else {
        expectValueCellValue(1, '');
        expectValueCellPlaceholder(1, 'Add value...');
    }
    expectKeyCellPlaceholder(1, 'Add key...');
};

const DipMapStringString = {
    ...XlComponent,
    clearFilter,
    clickAddButton,
    clickOnFilter,
    clickOnKeyHeader,
    clickShowPasswordButton,
    expectFilterPresent,
    expectAddButtonPresent,
    expectAddButtonEnabled,
    expectKeyCellValue,
    expectShowPasswordIconPresent,
    expectShowPasswordIconNotPresent,
    expectReadonlyKeyCell,
    expectReadonlyValueCell,
    expectKeyCellPlaceholder,
    expectDuplicatedKey,
    expectRemoveEntryPresent,
    expectRemoveEntryNotPresent,
    expectValueCellValue,
    expectValueCellPlaceholder,
    expectValueCellBePasswordType,
    expectValueCellBeTextType,
    removeEntry,
    setKeyValue,
    setEntry,
    setFilterValue,
    expectNoSearchResults,
    expectKeyInputFocused
};

export default DipMapStringString;
global.DipMapStringString = DipMapStringString;
